==> chemicals-0.1.5.tar.gz: chemicals-0.1.5/chemicals/numba_vectorized.py <==
# -*- coding: utf-8 -*-
"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
Copyright (C) 2020, Caleb Bell <Caleb.Andrew.Bell@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import division
import sys
import importlib.util
import types
import numpy as np
import chemicals as normal_chemicals
import numba
import fluids.numba

__all__ = []
__funcs = {}


replaced = {}
replaced, NUMERICS_SUBMOD = fluids.numba.create_numerics(replaced, vec=True)
normal = normal_chemicals

fluids.numba.transform_module(normal, __funcs, replaced, vec=True)

globals().update(__funcs)
globals().update(replaced)

==> chemicals-1.0.14.tar.gz: chemicals-1.0.14/chemicals/numba_vectorized.py <==
# -*- coding: utf-8 -*-
"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
Copyright (C) 2020, Caleb Bell <Caleb.Andrew.Bell@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import division
import sys
import importlib.util
import types
import numpy as np
import chemicals as normal_chemicals
import numba
import fluids.numba
import chemicals.numba

__all__ = []
__funcs = {}


replaced = {}
# replaced, NUMERICS_SUBMOD = fluids.numba.create_numerics(replaced, vec=True)
# normal = normal_chemicals

# fluids.numba.transform_module(normal, __funcs, replaced, vec=True)

replaced = fluids.numba.numerics_dict.copy()
orig_file = __file__
chemicals.numba.transform_complete_chemicals(replaced, __funcs, __all__, normal_chemicals, vec=True)


globals().update(__funcs)
globals().update(replaced)
__name__ = chemicals.numba
__file__ = orig_file
